# is-even

![PyPI](https://img.shields.io/pypi/v/is-even) ![PyPI - Downloads](https://img.shields.io/pypi/dm/is-even) ![GitHub branch checks state](https://img.shields.io/github/checks-status/victorbnl/is-even/main)

> Return true if the given number is even

## Install

Install with [pip](https://pypi.org/project/pip/)

## Usage

```python
from is_even import isEven

isEven(0)
# => True
isEven('1')
# => False
isEven(2)
# => True
isEven('3')
# => False
```
